@@ -16,7 +16,7 @@
  *  It does not contain relationships (even if they are classifiers) like generalizations, associations.
  *  \see http://www.omg.org/spec/UML/
  */
-static const char *DATA_DATABASE_CREATE_CLASSIFIERINSTANCE_TABLE =
+static const char *DATA_DATABASE_CREATE_CLASSIFIER_TABLE =
     "CREATE TABLE IF NOT EXISTS classifiers ( "
         "id INTEGER PRIMARY KEY ASC, "
         "main_type INTEGER, "
@@ -25,7 +25,8 @@ static const char *DATA_DATABASE_CREATE_CLASSIFIERINSTANCE_TABLE =
         "description TEXT, "
         "x_order INTEGER, "
         "y_order INTEGER, "
-        "list_order INTEGER "
+        "list_order INTEGER, "
+        "uuid TEXT NOT NULL DEFAULT \'\'"  /* DEFAULT needed in case a new DB is modified by an old program version */
     ");";
 
 /*!
@@ -39,15 +40,43 @@ static const char *DATA_DATABASE_CREATE_CLASSIFIERORDERING_INDEX =
     ");";
 */
 
+#if 0
 /*!
  *  \brief string constant to update an sql database table
  *
  *  This command extends classifiers by list_order field.
  *  \see http://sqlite.org/lang_altertable.html
  */
-static const char *DATA_DATABASE_ALTER_CLASSIFIERINSTANCE_TABLE_1 =
+static const char *DATA_DATABASE_ALTER_CLASSIFIER_TABLE_1 =
     "ALTER TABLE classifiers "
     "ADD COLUMN list_order INTEGER;";
+#endif
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  The DEFAULT clause is needed to convert the existing records to the new format
+ *  and in case a new database is modified by an old program version.
+ *
+ *  This command extends classifiers by a uuid field.
+ */
+static const char *DATA_DATABASE_ALTER_CLASSIFIER_TABLE_UUID =
+    "ALTER TABLE classifiers "
+    "ADD COLUMN uuid TEXT NOT NULL DEFAULT \'\';";
+
+#define DATA_DATABASE_CREATE_UUID \
+"lower(hex( randomblob(4)) || '-' || hex( randomblob(2))"\
+" || '-' || '4' || substr( hex( randomblob(2)), 2) || '-' || substr('89AB', 1 + (abs(random()) % 4) , 1) ||"\
+" substr(hex(randomblob(2)), 2) || '-' || hex(randomblob(6)))"
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  A uuid is generated and updated wherever missing.
+ *  The subselect-WHERE clause is needed to generate for each row a different uuid.
+ */
+static const char *DATA_DATABASE_UPDATE_CLASSIFIER_UUID =
+    "UPDATE classifiers SET uuid=(SELECT " DATA_DATABASE_CREATE_UUID " WHERE classifiers.id!=-1) WHERE uuid=\'\';";
 
 /*!
  *  \brief string constant to create an sql database table
@@ -55,7 +84,7 @@ static const char *DATA_DATABASE_ALTER_CLASSIFIERINSTANCE_TABLE_1 =
  *  This table contains instances of generalizations, associations (which are relationships)
  *  \see http://www.omg.org/spec/UML/
  */
-static const char *DATA_DATABASE_CREATE_RELATIONSHIPINSTANCE_TABLE =
+static const char *DATA_DATABASE_CREATE_RELATIONSHIP_TABLE =
     "CREATE TABLE IF NOT EXISTS relationships ( "
         "id INTEGER PRIMARY KEY ASC, "
         "main_type INTEGER, "
@@ -66,6 +95,7 @@ static const char *DATA_DATABASE_CREATE_RELATIONSHIPINSTANCE_TABLE =
         "list_order INTEGER, "
         "from_feature_id INTEGER DEFAULT NULL, "  /* DEFAULT needed in case a new DB is modified by an old program version */
         "to_feature_id INTEGER DEFAULT NULL, "  /* DEFAULT needed in case a new DB is modified by an old program version */
+        "uuid TEXT NOT NULL DEFAULT \'\', "  /* DEFAULT needed in case a new DB is modified by an old program version */
         "FOREIGN KEY(from_classifier_id) REFERENCES classifiers(id), "
         "FOREIGN KEY(to_classifier_id) REFERENCES classifiers(id), "
         "FOREIGN KEY(from_feature_id) REFERENCES features(id), "
@@ -82,29 +112,53 @@ static const char *DATA_DATABASE_CREATE_RELATIONSHIPORDERING_INDEX =
     ");";
 */
 
+#if 0
 /*!
  *  \brief string constant to update an sql database table
  *
- *  The DEFAULT clause is needed to convert the existing records to the new format.
+ *  The DEFAULT clause is needed to convert the existing records to the new format
+ *  and in case a new database is modified by an old program version.
  *
  *  This command extends relationships by from_feature_id field.
  *  \see http://sqlite.org/lang_altertable.html
  */
-static const char *DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_1 =
+static const char *DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_1 =
     "ALTER TABLE relationships "
     "ADD COLUMN from_feature_id INTEGER DEFAULT NULL;";
 
 /*!
  *  \brief string constant to update an sql database table
  *
- *  The DEFAULT clause is needed to convert the existing records to the new format.
+ *  The DEFAULT clause is needed to convert the existing records to the new format
+ *  and in case a new database is modified by an old program version.
  *
  *  This command extends relationships by to_feature_id field.
- *  \see http://sqlite.org/lang_altertable.html
  */
-static const char *DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_2 =
+static const char *DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_2 =
     "ALTER TABLE relationships "
     "ADD COLUMN to_feature_id INTEGER DEFAULT NULL;";
+#endif
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  The DEFAULT clause is needed to convert the existing records to the new format
+ *  and in case a new database is modified by an old program version.
+ *
+ *  This command extends relationships by a uuid field.
+ */
+static const char *DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_UUID =
+    "ALTER TABLE relationships "
+    "ADD COLUMN uuid TEXT NOT NULL DEFAULT \'\';";
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  A uuid is generated and updated wherever missing.
+ *  The subselect-WHERE clause is needed to generate for each row a different uuid.
+ */
+static const char *DATA_DATABASE_UPDATE_RELATIONSHIP_UUID =
+    "UPDATE relationships SET uuid=(SELECT " DATA_DATABASE_CREATE_UUID " WHERE relationships.id!=-1) WHERE uuid=\'\';";
 
 /*!
  *  \brief string constant to create an sql database table
@@ -112,7 +166,7 @@ static const char *DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_2 =
  *  This table contains instances of attributes (which are properties which are features).
  *  \see http://www.omg.org/spec/UML/
  */
-static const char *DATA_DATABASE_CREATE_FEATUREINSTANCE_TABLE =
+static const char *DATA_DATABASE_CREATE_FEATURE_TABLE =
     "CREATE TABLE IF NOT EXISTS features ( "
         "id INTEGER PRIMARY KEY ASC, "
         "main_type INTEGER, "
@@ -121,6 +175,7 @@ static const char *DATA_DATABASE_CREATE_FEATUREINSTANCE_TABLE =
         "value TEXT, "
         "description TEXT, "
         "list_order INTEGER, "
+        "uuid TEXT NOT NULL DEFAULT \'\', "  /* DEFAULT needed in case a new DB is modified by an old program version */
         "FOREIGN KEY(classifier_id) REFERENCES classifiers(id) "
     ");";
 
@@ -134,6 +189,27 @@ static const char *DATA_DATABASE_CREATE_FEATUREORDERING_INDEX =
     ");";
 */
 
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  The DEFAULT clause is needed to convert the existing records to the new format
+ *  and in case a new database is modified by an old program version.
+ *
+ *  This command extends featues by a uuid field.
+ */
+static const char *DATA_DATABASE_ALTER_FEATURE_TABLE_UUID =
+    "ALTER TABLE features "
+    "ADD COLUMN uuid TEXT NOT NULL DEFAULT \'\';";
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  A uuid is generated and updated wherever missing.
+ *  The subselect-WHERE clause is needed to generate for each row a different uuid.
+ */
+static const char *DATA_DATABASE_UPDATE_FEATURE_UUID =
+    "UPDATE features SET uuid=(SELECT " DATA_DATABASE_CREATE_UUID " WHERE features.id!=-1) WHERE uuid=\'\';";
+
 /*!
  *  \brief string constant to create an sql database table
  */
@@ -145,6 +221,8 @@ static const char *DATA_DATABASE_CREATE_DIAGRAM_TABLE =
         "name TEXT, "
         "description TEXT, "
         "list_order INTEGER, "
+        "display_flags INTEGER NOT NULL DEFAULT 0, "  /* DEFAULT needed in case a new DB is modified by an old program version */
+        "uuid TEXT NOT NULL DEFAULT \'\', "  /* DEFAULT needed in case a new DB is modified by an old program version */
         "FOREIGN KEY(parent_id) REFERENCES diagrams(id) "
     ");";
 
@@ -158,6 +236,40 @@ static const char *DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX =
     ");";
 */
 
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  The DEFAULT clause is needed to convert the existing records to the new format
+ *  and in case a new database is modified by an old program version.
+ *
+ *  This command extends diagrams by display_flags field.
+ */
+static const char *DATA_DATABASE_ALTER_DIAGRAM_TABLE_1 =
+    "ALTER TABLE diagrams "
+    "ADD COLUMN display_flags INTEGER NOT NULL DEFAULT 0;";
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  The DEFAULT clause is needed to convert the existing records to the new format
+ *  and in case a new database is modified by an old program version.
+ *
+ *  This command extends diagrams by a uuid field.
+ */
+static const char *DATA_DATABASE_ALTER_DIAGRAM_TABLE_UUID =
+    "ALTER TABLE diagrams "
+    "ADD COLUMN uuid TEXT NOT NULL DEFAULT \'\';";
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  A uuid is generated and updated wherever missing.
+ *  The subselect-WHERE clause is needed to generate for each row a different uuid.
+ */
+static const char *DATA_DATABASE_UPDATE_DIAGRAM_UUID =
+    "UPDATE diagrams SET uuid=(SELECT " DATA_DATABASE_CREATE_UUID " WHERE diagrams.id!=-1) WHERE uuid=\'\';";
+
+#if 0
 /*!
  *  \brief string constant to update an sql database table
  *
@@ -165,22 +277,25 @@ static const char *DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX =
  */
 static const char *DATA_DATABASE_UPDATE_DIAGRAM_ROOT_PARENT =
     "UPDATE diagrams SET parent_id=NULL WHERE parent_id=-1;";
+#endif
 
 /*!
  *  \brief string constant to create an sql database table
  */
-static const char *DATA_DATABASE_CREATE_DIAGRAMELEMENTS_TABLE =
+static const char *DATA_DATABASE_CREATE_DIAGRAMELEMENT_TABLE =
     "CREATE TABLE IF NOT EXISTS diagramelements ( "
         "id INTEGER PRIMARY KEY ASC, "
         "diagram_id INTEGER, "
         "classifier_id INTEGER, "
         "display_flags INTEGER, "
         "focused_feature_id INTEGER DEFAULT NULL, "  /* DEFAULT needed in case a new DB is modified by an old program version */
+        "uuid TEXT NOT NULL DEFAULT \'\', "  /* DEFAULT needed in case a new DB is modified by an old program version */
         "FOREIGN KEY(diagram_id) REFERENCES diagrams(id), "
         "FOREIGN KEY(classifier_id) REFERENCES classifiers(id), "
         "FOREIGN KEY(focused_feature_id) REFERENCES feature(id) "
     ");";
 
+#if 0
 /*!
  *  \brief string constant to update an sql database table
  *
@@ -189,93 +304,42 @@ static const char *DATA_DATABASE_CREATE_DIAGRAMELEMENTS_TABLE =
  *  This command extends diagramelements by to_feature_id field.
  *  \see http://sqlite.org/lang_altertable.html
  */
-static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 =
+static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_1 =
     "ALTER TABLE diagramelements "
     "ADD COLUMN focused_feature_id INTEGER DEFAULT NULL;";
+#endif
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  The DEFAULT clause is needed to convert the existing records to the new format.
+ *
+ *  This command extends diagramelements by a uuid field.
+ *  \see http://sqlite.org/lang_altertable.html
+ */
+static const char *DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_UUID =
+    "ALTER TABLE diagramelements "
+    "ADD COLUMN uuid TEXT NOT NULL DEFAULT \'\';";
+
+/*!
+ *  \brief string constant to update an sql database table
+ *
+ *  A uuid is generated and updated wherever missing.
+ *  The subselect-WHERE clause is needed to generate for each row a different uuid.
+ */
+static const char *DATA_DATABASE_UPDATE_DIAGRAMELEMENT_UUID =
+    "UPDATE diagramelements SET uuid=(SELECT " DATA_DATABASE_CREATE_UUID " WHERE diagramelements.id!=-1) WHERE uuid=\'\';";
 
 data_error_t data_database_private_initialize_tables( data_database_t *this_ )
 {
     TRACE_BEGIN();
-
-    int sqlite_err;
-    char *error_msg = NULL;
     data_error_t result = DATA_ERROR_NONE;
-    sqlite3 *db = (*this_).db;
 
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_CLASSIFIERINSTANCE_TABLE );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_CLASSIFIERINSTANCE_TABLE, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_CLASSIFIERINSTANCE_TABLE );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
-
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_RELATIONSHIPINSTANCE_TABLE );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_RELATIONSHIPINSTANCE_TABLE, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_RELATIONSHIPINSTANCE_TABLE );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
-
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_FEATUREINSTANCE_TABLE );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_FEATUREINSTANCE_TABLE, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_FEATUREINSTANCE_TABLE );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
-
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_DIAGRAM_TABLE );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_DIAGRAM_TABLE, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_DIAGRAM_TABLE );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
-
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_DIAGRAMELEMENTS_TABLE );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_DIAGRAMELEMENTS_TABLE, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_DIAGRAMELEMENTS_TABLE );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_CLASSIFIER_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_RELATIONSHIP_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_FEATURE_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_DIAGRAM_TABLE, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_DIAGRAMELEMENT_TABLE, false );
 
     TRACE_END_ERR( result );
     return result;
@@ -284,191 +348,58 @@ data_error_t data_database_private_initialize_tables( data_database_t *this_ )
 data_error_t data_database_private_initialize_indexes( data_database_t *this_ )
 {
     TRACE_BEGIN();
-
     data_error_t result = DATA_ERROR_NONE;
+
     /*
-    int sqlite_err;
-    char *error_msg = NULL;
-    sqlite3 *db = (*this_).db;
-
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_CLASSIFIERORDERING_INDEX );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_CLASSIFIERORDERING_INDEX, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_CLASSIFIERORDERING_INDEX );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
-
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_RELATIONSHIPORDERING_INDEX );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_RELATIONSHIPORDERING_INDEX, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_RELATIONSHIPORDERING_INDEX );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
-
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_FEATUREORDERING_INDEX );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_FEATUREORDERING_INDEX, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_FEATUREORDERING_INDEX );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
-
-    TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX );
-    sqlite_err = sqlite3_exec( db, DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX, NULL, NULL, &error_msg );
-    if ( SQLITE_OK != sqlite_err )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX );
-        TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-        result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-    }
-    if ( error_msg != NULL )
-    {
-        TSLOG_ERROR_STR( "sqlite3_exec() failed:", error_msg );
-        sqlite3_free( error_msg );
-        error_msg = NULL;
-    }
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_CLASSIFIERORDERING_INDEX, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_RELATIONSHIPORDERING_INDEX, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_FEATUREORDERING_INDEX, false );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_CREATE_DIAGRAMORDERING_INDEX, false );
     */
 
     TRACE_END_ERR( result );
     return result;
 }
 
-data_error_t data_database_upgrade_tables( data_database_t *this_ )
+data_error_t data_database_private_upgrade_tables( data_database_t *this_ )
 {
     TRACE_BEGIN();
-    int sqlite_err;
-    char *error_msg = NULL;
     data_error_t result = DATA_ERROR_NONE;
-    sqlite3 *db = (*this_).db;
 
-    if ( ! (*this_).is_open )
+#if 0
+    /* update table relationships from version 1.0.0 to later versions */
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_1, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_2, true );
+
+    /* update table diagramelements from version 1.0.0 to later versions */
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_1, true );
+
+    /* update table diagrams from version 1.0.0 to later versions */
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_DIAGRAM_ROOT_PARENT, true );
+
+    /* update table classifiers from version 1.4.0 or earlier to 1.5.0 or later versions */
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_CLASSIFIER_TABLE_1, true );
+#endif
+
+    /* update table classifiers from version 1.32.1 or earlier to later versions with diagram.display_flags */
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAM_TABLE_1, true );
+
+    /* update all 5 tables from version 1.32.1 (no uuid) to later versions with uuid field */
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_CLASSIFIER_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_CLASSIFIER_UUID, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_RELATIONSHIP_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_RELATIONSHIP_UUID, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_FEATURE_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_FEATURE_UUID, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAM_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_DIAGRAM_UUID, true );
+    data_database_private_exec_sql( this_, DATA_DATABASE_ALTER_DIAGRAMELEMENT_TABLE_UUID, true );
+    result |= data_database_private_exec_sql( this_, DATA_DATABASE_UPDATE_DIAGRAMELEMENT_UUID, true );
+
+    if ( ( result & DATA_ERROR_READ_ONLY_DB ) != DATA_ERROR_NONE )
     {
-        TRACE_INFO("data_database_upgrade_tables called on database that was not open.");
-        result |= DATA_ERROR_INVALID_REQUEST;
-    }
-    else
-    {
-        /* update table relationships from version 1.0.0 to later versions */
-
-        TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_1 );
-        sqlite_err = sqlite3_exec( db, DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_1, NULL, NULL, &error_msg );
-        if ( SQLITE_OK != sqlite_err )
-        {
-            /* this command will fail whenever the database already has a suitable format */
-            TRACE_INFO_STR( "sqlite3_exec() failed:", DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_1 );
-            TRACE_INFO_INT( "sqlite3_exec() failed:", sqlite_err );
-        }
-        else
-        {
-            TSLOG_WARNING_STR( "sqlite3_exec() altered a table:", DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_1 );
-        }
-        if ( error_msg != NULL )
-        {
-            TRACE_INFO_STR( "sqlite3_exec() failed:", error_msg );
-            sqlite3_free( error_msg );
-            error_msg = NULL;
-        }
-
-        TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_2 );
-        sqlite_err = sqlite3_exec( db, DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_2, NULL, NULL, &error_msg );
-        if ( SQLITE_OK != sqlite_err )
-        {
-            /* this command will fail whenever the database already has a suitable format */
-            TRACE_INFO_STR( "sqlite3_exec() failed:", DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_2 );
-            TRACE_INFO_INT( "sqlite3_exec() failed:", sqlite_err );
-        }
-        else
-        {
-            TSLOG_WARNING_STR( "sqlite3_exec() altered a table:", DATA_DATABASE_ALTER_RELATIONSHIPINSTANCE_TABLE_2 );
-        }
-        if ( error_msg != NULL )
-        {
-            TRACE_INFO_STR( "sqlite3_exec() failed:", error_msg );
-            sqlite3_free( error_msg );
-            error_msg = NULL;
-        }
-
-        /* update table diagramelements from version 1.0.0 to later versions */
-
-        TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 );
-        sqlite_err = sqlite3_exec( db, DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1, NULL, NULL, &error_msg );
-        if ( SQLITE_OK != sqlite_err )
-        {
-            /* this command will fail whenever the database already has a suitable format */
-            TRACE_INFO_STR( "sqlite3_exec() failed:", DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 );
-            TRACE_INFO_INT( "sqlite3_exec() failed:", sqlite_err );
-        }
-        else
-        {
-            TSLOG_WARNING_STR( "sqlite3_exec() altered a table:", DATA_DATABASE_ALTER_DIAGRAMELEMENTS_TABLE_1 );
-        }
-        if ( error_msg != NULL )
-        {
-            TRACE_INFO_STR( "sqlite3_exec() failed:", error_msg );
-            sqlite3_free( error_msg );
-            error_msg = NULL;
-        }
-
-        /* update table diagrams from version 1.0.0 to later versions */
-
-        TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_UPDATE_DIAGRAM_ROOT_PARENT );
-        sqlite_err = sqlite3_exec( db, DATA_DATABASE_UPDATE_DIAGRAM_ROOT_PARENT, NULL, NULL, &error_msg );
-        if ( SQLITE_OK != sqlite_err )
-        {
-            TSLOG_ERROR_STR( "sqlite3_exec() failed:", DATA_DATABASE_UPDATE_DIAGRAM_ROOT_PARENT );
-            TSLOG_ERROR_INT( "sqlite3_exec() failed:", sqlite_err );
-            result |= (sqlite_err == SQLITE_READONLY) ? DATA_ERROR_READ_ONLY_DB : DATA_ERROR_AT_DB;
-        }
-        if ( error_msg != NULL )
-        {
-            TRACE_INFO_STR( "sqlite3_exec() failed:", error_msg );
-            sqlite3_free( error_msg );
-            error_msg = NULL;
-        }
-
-        /* update table classifiers from version 1.4.0 or earlier to 1.5.0 or later versions */
-
-        TSLOG_EVENT_STR( "sqlite3_exec:", DATA_DATABASE_ALTER_CLASSIFIERINSTANCE_TABLE_1 );
-        sqlite_err = sqlite3_exec( db, DATA_DATABASE_ALTER_CLASSIFIERINSTANCE_TABLE_1, NULL, NULL, &error_msg );
-        if ( SQLITE_OK != sqlite_err )
-        {
-            /* this command will fail whenever the database already has a suitable format */
-            TRACE_INFO_STR( "sqlite3_exec() failed:", DATA_DATABASE_ALTER_CLASSIFIERINSTANCE_TABLE_1 );
-            TRACE_INFO_INT( "sqlite3_exec() failed:", sqlite_err );
-        }
-        else
-        {
-            TSLOG_WARNING_STR( "sqlite3_exec() altered a table:", DATA_DATABASE_ALTER_CLASSIFIERINSTANCE_TABLE_1 );
-        }
-        if ( error_msg != NULL )
-        {
-            TRACE_INFO_STR( "sqlite3_exec() failed:", error_msg );
-            sqlite3_free( error_msg );
-            error_msg = NULL;
-        }
+        TSLOG_EVENT( "sqlite3 database is read only." );
+        result = result & ~DATA_ERROR_READ_ONLY_DB;
     }
 
     TRACE_END_ERR( result );
@@ -534,6 +465,10 @@ data_error_t data_database_private_open ( data_database_t *this_, const char* db
             {
                 init_err = data_database_private_initialize_indexes( this_ );
             }
+            if ( init_err == DATA_ERROR_NONE )
+            {
+                init_err = data_database_private_upgrade_tables( this_ );
+            }
 
             if ( init_err == DATA_ERROR_NONE )
             {
