@@ -1,8 +1,10 @@
 /* File: io_exporter.c; Copyright and License: see below */
 
 #include "io_exporter.h"
+#include "xhtml/xhtml_stylesheet_writer.h"
 #include "stream/universal_file_output_stream.h"
 #include "stream/universal_output_stream.h"
+#include "xmi/xmi_writer_pass.h"
 #include "trace.h"
 #include "tslog.h"
 #include <gtk/gtk.h>
@@ -95,6 +97,11 @@ int io_exporter_export_files( io_exporter_t *this_,
             export_err |= io_exporter_private_export_document_file( this_, IO_FILE_FORMAT_CSS, target_folder, document_file_name, io_export_stat );
         }
 
+        if ( ( export_type & IO_FILE_FORMAT_JSON ) != 0 )
+        {
+            export_err |= io_exporter_private_export_document_file( this_, IO_FILE_FORMAT_JSON, target_folder, document_file_name, io_export_stat );
+        }
+
         if ( ( export_type & IO_FILE_FORMAT_XMI2 ) != 0 )
         {
             export_err |= io_exporter_private_export_document_file( this_, IO_FILE_FORMAT_XMI2, target_folder, document_file_name, io_export_stat );
@@ -211,19 +218,24 @@ int io_exporter_private_export_image_files( io_exporter_t *this_,
 
                 /* temporarily use the temp_model_traversal */
                 /* write file */
-                io_format_writer_init( &((*this_).temp_format_writer ), (*this_).db_reader, IO_FILE_FORMAT_TXT, output );
+                xhtml_element_writer_init( &((*this_).temp_format_writer ),
+                                           (*this_).db_reader,
+                                           IO_FILE_FORMAT_TXT,
+                                           io_export_stat,
+                                           output
+                                         );
                 io_export_diagram_traversal_init( &((*this_).temp_diagram_traversal),
                                                   (*this_).db_reader,
                                                   &((*this_).temp_input_data),
                                                   io_export_stat,
-                                                  &((*this_).temp_format_writer)
+                                                  xhtml_element_writer_get_element_writer( &((*this_).temp_format_writer) )
                                                 );
-                write_err |= io_format_writer_write_header( &((*this_).temp_format_writer), "DUMMY_TITLE" );
+                write_err |= xhtml_element_writer_write_header( &((*this_).temp_format_writer), "DUMMY_TITLE" );
                 write_err |= io_export_diagram_traversal_begin_and_walk_diagram ( &((*this_).temp_diagram_traversal), diagram_id, "NO_IMAGE_FILE" );
-                write_err |= io_export_diagram_traversal_end_diagram ( &((*this_).temp_diagram_traversal) );
-                write_err |= io_format_writer_write_footer( &((*this_).temp_format_writer) );
+                write_err |= io_export_diagram_traversal_end_diagram ( &((*this_).temp_diagram_traversal), diagram_id );
+                write_err |= xhtml_element_writer_write_footer( &((*this_).temp_format_writer) );
                 io_export_diagram_traversal_destroy( &((*this_).temp_diagram_traversal) );
-                io_format_writer_destroy( &((*this_).temp_format_writer ) );
+                xhtml_element_writer_destroy( &((*this_).temp_format_writer ) );
 
                 if ( 0 != write_err )
                 {
@@ -232,11 +244,11 @@ int io_exporter_private_export_image_files( io_exporter_t *this_,
                 }
 
                 /* close file */
-                result |= universal_output_stream_close( output );
+                result |= universal_file_output_stream_close( &text_output );
             }
 
             result |= universal_file_output_stream_destroy( &text_output );
-            
+
             data_stat_inc_count ( io_export_stat, DATA_TABLE_DIAGRAM, DATA_STAT_SERIES_EXPORTED );
         }
     }
@@ -313,6 +325,12 @@ int io_exporter_private_export_document_file( io_exporter_t *this_,
         }
         break;
 
+        case IO_FILE_FORMAT_JSON:
+        {
+            utf8stringbuf_append_str( (*this_).temp_filename, ".json" );
+        }
+        break;
+
         case IO_FILE_FORMAT_XMI2:
         {
             utf8stringbuf_append_str( (*this_).temp_filename, ".xmi" );
@@ -328,61 +346,113 @@ int io_exporter_private_export_document_file( io_exporter_t *this_,
     }
     TSLOG_EVENT_STR( "exporting diagrams to document file:", utf8stringbuf_get_string( (*this_).temp_filename ) );
 
-    export_err |= universal_output_stream_open( output, utf8stringbuf_get_string( (*this_).temp_filename ) );
+    export_err |= universal_file_output_stream_open( &file_output, utf8stringbuf_get_string( (*this_).temp_filename ) );
     if ( export_err == 0 )
     {
         /* write file */
         if ( IO_FILE_FORMAT_CSS == export_type )
         {
-            io_format_writer_init( &((*this_).temp_format_writer ), (*this_).db_reader, export_type, output );
-            export_err |= io_format_writer_write_stylesheet( &((*this_).temp_format_writer) );
-            io_format_writer_destroy( &((*this_).temp_format_writer ) );
+            xhtml_stylesheet_writer_t css_writer;
+            xhtml_stylesheet_writer_init( &css_writer, output );
+            export_err |= xhtml_stylesheet_writer_write_stylesheet( &css_writer );
+            xhtml_stylesheet_writer_destroy( &css_writer );
         }
         else if ( IO_FILE_FORMAT_XMI2 == export_type )
         {
-            xmi_element_writer_init( &((*this_).temp_xmi_writer ), (*this_).db_reader, io_export_stat, output );
+            xmi_element_writer_init( &((*this_).temp_xmi_writer ), io_export_stat, output );
             /* init the model_traversal */
             io_export_model_traversal_init( &((*this_).temp_model_traversal),
                                             (*this_).db_reader,
                                             &((*this_).temp_input_data),
                                             io_export_stat,
-                                            &((*this_).temp_xmi_writer)
+                                            xmi_element_writer_get_element_writer( &((*this_).temp_xmi_writer) )
                                           );
             /* write the document */
             export_err |= xmi_element_writer_write_header( &((*this_).temp_xmi_writer), document_file_name );
             export_err |= xmi_element_writer_start_main( &((*this_).temp_xmi_writer), document_file_name );
-            xmi_element_writer_set_mode( &((*this_).temp_xmi_writer ), IO_WRITER_PASS_BASE );
+            xmi_element_writer_set_mode( &((*this_).temp_xmi_writer ), XMI_WRITER_PASS_BASE );
             export_err |= io_export_model_traversal_walk_model_nodes( &((*this_).temp_model_traversal) );
             export_err |= xmi_element_writer_end_main( &((*this_).temp_xmi_writer) );
-            xmi_element_writer_set_mode( &((*this_).temp_xmi_writer ), IO_WRITER_PASS_PROFILE );
+            xmi_element_writer_set_mode( &((*this_).temp_xmi_writer ), XMI_WRITER_PASS_PROFILE );
             export_err |= io_export_model_traversal_walk_model_nodes( &((*this_).temp_model_traversal) );
             export_err |= xmi_element_writer_write_footer( &((*this_).temp_xmi_writer) );
 
             io_export_model_traversal_destroy( &((*this_).temp_model_traversal) );
             xmi_element_writer_destroy( &((*this_).temp_xmi_writer ) );
         }
+        else if ( IO_FILE_FORMAT_JSON == export_type )
+        {
+            json_element_writer_init( &((*this_).temp_json_writer ), io_export_stat, output );
+            export_err |= json_element_writer_write_header( &((*this_).temp_json_writer), document_file_name );
+
+            /* init the diagram_traversal */
+            {
+                io_export_diagram_traversal_init( &((*this_).temp_diagram_traversal),
+                                                  (*this_).db_reader,
+                                                  &((*this_).temp_input_data),
+                                                  io_export_stat,
+                                                  json_element_writer_get_element_writer( &((*this_).temp_json_writer) )
+                                                );
+                /* write the document */
+                json_element_writer_set_mode( &((*this_).temp_json_writer ), JSON_WRITER_PASS_VIEWS );
+                export_err |= json_element_writer_start_main( &((*this_).temp_json_writer), document_file_name );
+                export_err |= io_exporter_private_export_document_part( this_, DATA_ID_VOID, IO_EXPORTER_MAX_DIAGRAM_TREE_DEPTH, io_export_stat );
+                export_err |= json_element_writer_end_main( &((*this_).temp_json_writer) );
+
+                io_export_diagram_traversal_destroy( &((*this_).temp_diagram_traversal) );
+            }
+
+            /* init the model_traversal */
+            {
+                io_export_flat_traversal_init( &((*this_).temp_flat_traversal),
+                                               (*this_).db_reader,
+                                               io_export_stat,
+                                               json_element_writer_get_element_writer( &((*this_).temp_json_writer) )
+                                             );
+                /* write the document */
+                json_element_writer_set_mode( &((*this_).temp_json_writer ), JSON_WRITER_PASS_NODES );
+                export_err |= json_element_writer_start_main( &((*this_).temp_json_writer), document_file_name );
+                export_err |= io_export_flat_traversal_iterate_classifiers( &((*this_).temp_flat_traversal) );
+                export_err |= json_element_writer_end_main( &((*this_).temp_json_writer) );
+
+                json_element_writer_set_mode( &((*this_).temp_json_writer ), JSON_WRITER_PASS_EDGES );
+                export_err |= json_element_writer_start_main( &((*this_).temp_json_writer), document_file_name );
+                export_err |= io_export_flat_traversal_iterate_classifiers( &((*this_).temp_flat_traversal) );
+                export_err |= json_element_writer_end_main( &((*this_).temp_json_writer) );
+
+                io_export_flat_traversal_destroy( &((*this_).temp_flat_traversal) );
+            }
+
+            export_err |= json_element_writer_write_footer( &((*this_).temp_json_writer) );
+            json_element_writer_destroy( &((*this_).temp_json_writer ) );
+        }
         else
         {
-            io_format_writer_init( &((*this_).temp_format_writer ), (*this_).db_reader, export_type, output );
+            xhtml_element_writer_init( &((*this_).temp_format_writer ),
+                                       (*this_).db_reader,
+                                       export_type,
+                                       io_export_stat,
+                                       output
+                                     );
             /* init the diagram_traversal */
             io_export_diagram_traversal_init( &((*this_).temp_diagram_traversal),
                                               (*this_).db_reader,
                                               &((*this_).temp_input_data),
                                               io_export_stat,
-                                              &((*this_).temp_format_writer)
+                                              xhtml_element_writer_get_element_writer( &((*this_).temp_format_writer) )
                                             );
             /* write the document */
-            export_err |= io_format_writer_write_header( &((*this_).temp_format_writer), document_file_name );
+            export_err |= xhtml_element_writer_write_header( &((*this_).temp_format_writer), document_file_name );
             export_err |= io_exporter_private_export_table_of_contents( this_, DATA_ID_VOID, IO_EXPORTER_MAX_DIAGRAM_TREE_DEPTH, &((*this_).temp_format_writer) );
             export_err |= io_exporter_private_export_document_part( this_, DATA_ID_VOID, IO_EXPORTER_MAX_DIAGRAM_TREE_DEPTH, io_export_stat );
-            export_err |= io_format_writer_write_footer( &((*this_).temp_format_writer) );
+            export_err |= xhtml_element_writer_write_footer( &((*this_).temp_format_writer) );
 
             io_export_diagram_traversal_destroy( &((*this_).temp_diagram_traversal) );
-            io_format_writer_destroy( &((*this_).temp_format_writer ) );
+            xhtml_element_writer_destroy( &((*this_).temp_format_writer ) );
         }
 
         /* close file */
-        export_err |= universal_output_stream_close( output );
+        export_err |= universal_file_output_stream_close( &file_output );
     }
 
     export_err |= universal_file_output_stream_destroy( &file_output );
@@ -448,7 +518,7 @@ int io_exporter_private_export_document_part( io_exporter_t *this_,
     if ( DATA_ROW_ID_VOID != diagram_row_id )
     {
         /* write doc part */
-        export_err |= io_export_diagram_traversal_end_diagram( &((*this_).temp_diagram_traversal) );
+        export_err |= io_export_diagram_traversal_end_diagram( &((*this_).temp_diagram_traversal), diagram_id );
     }
 
     TRACE_END_ERR( export_err );
@@ -458,7 +528,7 @@ int io_exporter_private_export_document_part( io_exporter_t *this_,
 int io_exporter_private_export_table_of_contents( io_exporter_t *this_,
                                                   data_id_t diagram_id,
                                                   uint32_t max_recursion,
-                                                  io_format_writer_t *format_writer )
+                                                  xhtml_element_writer_t *format_writer )
 {
     TRACE_BEGIN();
     assert ( NULL != format_writer );
@@ -470,7 +540,7 @@ int io_exporter_private_export_table_of_contents( io_exporter_t *this_,
     {
         assert( data_id_get_table( &diagram_id ) == DATA_TABLE_DIAGRAM );
 
-        export_err |= io_format_writer_start_toc_entry( format_writer );
+        export_err |= xhtml_element_writer_start_toc_entry( format_writer );
 
         /* load data to be drawn */
         data_error_t db_err;
@@ -482,7 +552,7 @@ int io_exporter_private_export_table_of_contents( io_exporter_t *this_,
         }
         else
         {
-            export_err |= io_format_writer_write_toc_entry ( format_writer, &((*this_).temp_diagram) );
+            export_err |= xhtml_element_writer_write_toc_entry ( format_writer, &((*this_).temp_diagram) );
             data_diagram_destroy( &((*this_).temp_diagram) );
         }
     }
@@ -504,7 +574,7 @@ int io_exporter_private_export_table_of_contents( io_exporter_t *this_,
             const uint32_t child_count = data_small_set_get_count( &the_set );
             if ( child_count != 0 )
             {
-                export_err |= io_format_writer_start_toc_sublist( format_writer );
+                export_err |= xhtml_element_writer_start_toc_sublist( format_writer );
                 for ( uint32_t pos = 0; pos < child_count; pos ++ )
                 {
                     data_id_t probe_id = data_small_set_get_id( &the_set, pos );
@@ -513,7 +583,7 @@ int io_exporter_private_export_table_of_contents( io_exporter_t *this_,
 
                     data_id_destroy( &probe_id );
                 }
-                export_err |= io_format_writer_end_toc_sublist ( format_writer );
+                export_err |= xhtml_element_writer_end_toc_sublist ( format_writer );
             }
         }
         data_small_set_destroy( &the_set );
@@ -522,7 +592,7 @@ int io_exporter_private_export_table_of_contents( io_exporter_t *this_,
     /* end toc entry */
     if ( DATA_ROW_ID_VOID != diagram_row_id )
     {
-        export_err |= io_format_writer_end_toc_entry( format_writer );
+        export_err |= xhtml_element_writer_end_toc_entry( format_writer );
     }
 
     TRACE_END_ERR( export_err );
@@ -548,7 +618,7 @@ int io_exporter_private_get_filename_for_diagram( io_exporter_t *this_,
     else
     {
         const char *diag_name;
-        diag_name = data_diagram_get_name_ptr( &((*this_).temp_diagram) );
+        diag_name = data_diagram_get_name_const( &((*this_).temp_diagram) );
 
         /* determine filename */
         data_id_to_utf8stringbuf( &diagram_id, filename );
