@@ -2,9 +2,10 @@
 
 #include "unit/data_change_notifier_test.h"
 #include "unit/data_small_set_test.h"
+#include "unit/data_uuid_test.h"
 #include "unit/data_rules_test.h"
 #include "unit/data_database_listener_test.h"
-#include "unit/data_database_reader_test.h"
+#include "integration/data_database_reader_test.h"
 #include "unit/ctrl_diagram_controller_test.h"
 #include "unit/ctrl_controller_test.h"
 #include "unit/ctrl_classifier_controller_test.h"
@@ -17,7 +18,7 @@
 #include "unit/geometry_non_linear_scale_test.h"
 #include "unit/gui_sketch_nav_tree_test.h"
 #include "unit/txt_writer_test.h"
-#include "unit/json_tokenizer_test.h"
+#include "unit/json_token_reader_test.h"
 #include "unit/json_import_to_database_test.h"
 #include "unit/md_filter_test.h"
 #include "integration/io_export_model_traversal_test.h"
@@ -30,6 +31,11 @@
 #include "unit/universal_array_list_test.h"
 #include "unit/universal_memory_output_stream_test.h"
 #include "unit/universal_escaping_output_stream_test.h"
+#include "unit/universal_memory_input_stream_test.h"
+#include "unit/universal_buffer_input_stream_test.h"
+#include "unit/universal_buffer_output_stream_test.h"
+#include "unit/universal_memory_arena_test.h"
+#include "unit/universal_arena_list_test.h"
 #include "unit/utf8stringbuf_test.h"
 #include "unit/utf8codepoint_test.h"
 #include "unit/utf8codepointiterator_test.h"
@@ -115,13 +121,14 @@ int main (int argc, char *argv[]) {
     {
         test_runner_run_suite( &runner, data_small_set_test_get_list() );
         test_runner_run_suite( &runner, data_rules_test_get_list() );
+        test_runner_run_suite( &runner, data_uuid_test_get_list() );
         test_runner_run_suite( &runner, data_change_notifier_test_get_list() );
         test_runner_run_suite( &runner, data_database_listener_test_get_list() );
         test_runner_run_suite( &runner, geometry_rectangle_test_get_list() );
         test_runner_run_suite( &runner, geometry_connector_test_get_list() );
         test_runner_run_suite( &runner, geometry_non_linear_scale_test_get_list() );
         test_runner_run_suite( &runner, txt_writer_test_get_list() );
-        test_runner_run_suite( &runner, json_tokenizer_test_get_list() );
+        test_runner_run_suite( &runner, json_token_reader_test_get_list() );
         test_runner_run_suite( &runner, draw_classifier_contour_test_get_list() );
         test_runner_run_suite( &runner, pencil_classifier_composer_test_get_list() );
         test_runner_run_suite( &runner, pencil_layout_data_test_get_list() );
@@ -129,6 +136,11 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, universal_array_list_test_get_list() );
         test_runner_run_suite( &runner, universal_memory_output_stream_test_get_list() );
         test_runner_run_suite( &runner, universal_escaping_output_stream_test_get_list() );
+        test_runner_run_suite( &runner, universal_memory_input_stream_test_get_list() );
+        test_runner_run_suite( &runner, universal_buffer_input_stream_test_get_list() );
+        test_runner_run_suite( &runner, universal_buffer_output_stream_test_get_list() );
+        test_runner_run_suite( &runner, universal_memory_arena_test_get_list() );
+        test_runner_run_suite( &runner, universal_arena_list_test_get_list() );
         test_runner_run_suite( &runner, utf8codepoint_test_get_list() );
         test_runner_run_suite( &runner, utf8codepointiterator_test_get_list() );
         test_runner_run_suite( &runner, utf8stringbuf_test_get_list() );
