@@ -225,6 +225,15 @@ void pencil_relationship_layouter_private_propose_solutions ( pencil_relationshi
     TRACE_END();
 }
 
+static const geometry_3dir_t PENCIL_BAD_V_PATTERN1
+   = { .first = GEOMETRY_DIRECTION_LEFT,  .second = GEOMETRY_DIRECTION_DOWN,  .third = GEOMETRY_DIRECTION_LEFT };
+static const geometry_3dir_t PENCIL_BAD_V_PATTERN2
+   = { .first = GEOMETRY_DIRECTION_RIGHT, .second = GEOMETRY_DIRECTION_UP,    .third = GEOMETRY_DIRECTION_RIGHT };
+static const geometry_3dir_t PENCIL_BAD_H_PATTERN1
+   = { .first = GEOMETRY_DIRECTION_DOWN,  .second = GEOMETRY_DIRECTION_RIGHT, .third = GEOMETRY_DIRECTION_DOWN };
+static const geometry_3dir_t PENCIL_BAD_H_PATTERN2
+   = { .first = GEOMETRY_DIRECTION_UP,    .second = GEOMETRY_DIRECTION_LEFT,  .third = GEOMETRY_DIRECTION_UP };
+
 void pencil_relationship_layouter_private_select_solution ( pencil_relationship_layouter_t *this_,
                                                             const universal_array_index_sorter_t *sorted,
                                                             uint32_t sort_index,
@@ -270,6 +279,28 @@ void pencil_relationship_layouter_private_select_solution ( pencil_relationship_
         /* the more length, the more unwanted... */
         debts_of_current += geometry_connector_get_length( current_solution );
 
+        /* prefer left-hand angles over right-handed */
+        bool bad_pattern_h = false;
+        bool bad_pattern_v = false;
+        {
+
+            const geometry_3dir_t pattern = geometry_connector_get_directions( current_solution );
+            bad_pattern_v = geometry_3dir_equals( &pattern, &PENCIL_BAD_V_PATTERN1 )
+                || geometry_3dir_equals( &pattern, &PENCIL_BAD_V_PATTERN2 );
+            bad_pattern_h = geometry_3dir_equals( &pattern, &PENCIL_BAD_H_PATTERN1 )
+                || geometry_3dir_equals( &pattern, &PENCIL_BAD_H_PATTERN2 );
+            if ( bad_pattern_h || bad_pattern_v )
+            {
+                const double current_len = geometry_connector_get_length( current_solution );
+                const double object_dist = pencil_size_get_preferred_object_distance( (*this_).pencil_size );
+                if ( current_len > ( 4.0 * object_dist ) )
+                {
+                    /* current_solution is a long path and right-handed */
+                    debts_of_current += 0.2 * geometry_connector_get_length( current_solution );
+                }
+            }
+        }
+
         /* add debts for overlap to diagram boundary */
         {
             const geometry_rectangle_t connectors_bounds
@@ -319,15 +350,28 @@ void pencil_relationship_layouter_private_select_solution ( pencil_relationship_
                                      == data_relationship_get_from_classifier_row_id( current_relation_data ) );
             const bool same_to = ( data_relationship_get_to_classifier_row_id( probe_relation_data )
                                      == data_relationship_get_to_classifier_row_id( current_relation_data ) );
-            const bool one_same_emd = ( same_from != same_to );
+            const bool one_same_end = ( same_from != same_to );
             /* if probe and current have same type and (same source classifier xor same destination classifier), overlaps are ok */
-            if ( ! ( same_type && one_same_emd ) )
+            if ( ! ( same_type && one_same_end ) )
             {
                 const geometry_connector_t *const probe_shape
                     = layout_relationship_get_shape_const( probe_relationship );
                 const uint32_t intersects
                     = geometry_connector_count_connector_intersects( current_solution, probe_shape );
                 debts_of_current += 1000.0 * intersects;
+
+                if ( ( bad_pattern_h || bad_pattern_v ) && ( intersects > 0 ) )
+                {
+                    const geometry_3dir_t probe_pattern = geometry_connector_get_directions( probe_shape );
+                    const bool bad_probe_v = geometry_3dir_equals( &probe_pattern, &PENCIL_BAD_V_PATTERN1 )
+                        || geometry_3dir_equals( &probe_pattern, &PENCIL_BAD_V_PATTERN2 );
+                    const bool bad_probe_h = geometry_3dir_equals( &probe_pattern, &PENCIL_BAD_H_PATTERN1 )
+                        || geometry_3dir_equals( &probe_pattern, &PENCIL_BAD_H_PATTERN2 );
+                    if (( bad_pattern_h && bad_probe_v )||( bad_pattern_v && bad_probe_h ))
+                    {
+                         debts_of_current += 1000000.0;
+                    }
+                }
             }
         }
 
@@ -339,14 +383,9 @@ void pencil_relationship_layouter_private_select_solution ( pencil_relationship_
         }
     }
 
-    /*
-    static unsigned int random;
-    random ++;
-    index_of_best = random % solutions_count;
-    */
-
     /* the best */
     *out_index_of_best = index_of_best;
+    geometry_connector_trace( &(solutions[index_of_best]) );
 
     TRACE_END();
 }
